@@ -3,5 +3,5 @@ from pyramid.config import Configurator
 
 
 def main(global_config, **settings):
-	config = Configuratorsettings)
-	return config
+    config = Configurator(settings)
+    return config
